#!/bin/bash

# This file is installed from the qt5_up RPM and
# is used to differentiate what version of the
# qt designer is opened when the designer alias
# is entered from the command line

cyflex_version_info()
{
   #gather the version line from the version.dat file
   cat $1 | awk '/CYFLEX VERSION/ { print $0 } '
}

num_args=$#

if [ $num_args -gt 0 ]; then
   ui_filename=$1
fi

version_line=`cyflex_version_info /cyflex/bin/version.dat`

#break version_line up into tokens delimited by spaces
#and save tokens to the ADDR array
IFS=' '
read -ra ADDR <<< "$version_line"

if [[ "${ADDR[0]}" -eq "EXPERIMENTAL" ]]; 
then
   #the second token is the cyflex version number
   version_num="${ADDR[3]}"
else
   #the second token is the cyflex version number
   version_num="${ADDR[2]}"
fi

#break version number up into tokens delimited by .
#and save tokens to the ADDR array
IFS='.'
read -ra ADDR <<< "$version_num"

#concatenate major and minor token numbers together
major_minor_ver="${ADDR[0]}.${ADDR[1]}"

#calculate whether the major_minor version number is >= 6.3
#a 0 is returned if major_minor_ver is <  6.3
#a 1 is returned if major_minor_ver is >= 6.3

answer=`echo "$major_minor_ver >= 6.3" | bc `

if [ $answer -eq 1 ]; then

   # the version of cyflex is 6.3
   if [ $num_args -eq 0 ]; then
      ret= `/usr/local/Qt-5.12.3/bin/designer -style plastique &`
   else
      ret= `/usr/local/Qt-5.12.3/bin/designer -style plastique "$ui_filename" &`
   fi
else

   # the version of cyflex is less than 6.3
   if [ $num_args -eq 0 ]; then
      ret=`/usr/local/Trolltech/Qt-4.8.7/bin/designer &`
   else
      ret=`/usr/local/Trolltech/Qt-4.8.7/bin/designer "$ui_filename" &`
   fi
fi
